@@ -1715,7 +1715,7 @@ class SMTLinkTest extends SMTServiceHelper
             }
         }
         
-        if ( ($portCount <= 1) && (SMTOtuType::isOTH() || SMTOtuType::isOtu8KV2() || SMTOtuType::isMts8KV2()))
+        if ( ($portCount <= 1) && (SMTOtuType::isOTH() || SMTOtuType::isFTH7K() || SMTOtuType::isOtu8KV2()))
         {
             try
             {
