@@ -15,7 +15,7 @@ if grep -x 0 -q /sys/platform/uts_scan/i2c_master_op  /sys/platform/uts_scan/i2c
 fi
 
 # Search for 2k/4k module or 6k other than CAA
-if tail -n 4 /sys/platform/uts_scan/modules | grep -v CAA | tr -s "\t" " " | cut -d " " -f 3 | grep -v -x -q 0 ; then
+if grep -e "^[0-9]" /sys/platform/uts_scan/modules | grep -v CAA | tr -s "\t" " " | cut -d " " -f 3 | grep -v -x -q 0 ; then
   OTDR_SHOULD_RUN=1
 fi
 
